"""add lastBandwidthMetric

Peek Plugin Database Migration Script

Revision ID: 97d44e5aeb18
Revises: 4b0d6309e556
Create Date: 2023-02-23 15:39:49.570045

"""

# revision identifiers, used by Alembic.
revision = "97d44e5aeb18"
down_revision = "4b0d6309e556"
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "DeviceInfo",
        sa.Column("lastBandwidthMetric", sa.Integer(), nullable=True),
        schema="core_device",
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column("DeviceInfo", "lastBandwidthMetric", schema="core_device")
    # ### end Alembic commands ###
