
@import "@synerty/peek-plugin-base-js/src/styles/_variables";
@import "src/variables";

:host {
    display: flex;
    flex-direction: column;
    width: 100%;
}

nz-card {
    background: $container-background-color;
    border-radius: $border-radius;
    box-shadow: $box-shadow;
    margin-bottom: $general_padding_2;
    
    nz-table {
        th {
            white-space: nowrap;
            color: $font-color-primary;
            font-weight: $semi-bold;
        }
        
        td {
            vertical-align: middle;
            
            button {
                display: flex;
                align-items: center;
                justify-content: center;
                
                i {
                    font-size: $icon-size;
                }
            }
        }
    }
}

nz-switch {
    min-width: 80px;
}

.description-cell {
    max-width: 300px;
    word-wrap: break-word;
}

.version-cell {
    white-space: nowrap;
}

.action-cell {
    display: flex;
    gap: $general_padding_1;
    
    button {
        min-width: auto;
        padding: $general_padding_1;
    }
}